@@ -23,6 +23,30 @@ DATA_TYPE_CANOPEN_TIME = 14
 DATA_TYPE_COMPLEX_INTEL = 15
 DATA_TYPE_COMPLEX_MOTOROLA = 16
 
+DATA_TYPE_TO_STRING = dict(
+    enumerate(
+        [
+            "UNSIGNED_INTEL",
+            "UNSIGNED_MOTOROLA",
+            "SIGNED_INTEL",
+            "SIGNED_MOTOROLA",
+            "REAL_INTEL",
+            "REAL_MOTOROLA",
+            "STRING_LATIN_1",
+            "STRING_UTF_8",
+            "STRING_UTF_16_LE",
+            "STRING_UTF_16_BE",
+            "BYTEARRAY",
+            "MIME_SAMPLE",
+            "MIME_STREAM",
+            "CANOPEN_DATE",
+            "CANOPEN_TIME",
+            "COMPLEX_INTEL",
+            "COMPLEX_MOTOROLA",
+        ]
+    )
+)
+
 NON_SCALAR_TYPES = {
     DATA_TYPE_BYTEARRAY,
     DATA_TYPE_STRING_UTF_8,
@@ -72,14 +96,16 @@ SYNC_TYPE_ANGLE = 2
 SYNC_TYPE_DISTANCE = 3
 SYNC_TYPE_INDEX = 4
 
-CHANNEL_TYPE_TO_DESCRIPTION = {
-    CHANNEL_TYPE_VALUE: "value",
+SYNC_TYPE_TO_STRING = dict(enumerate(["NONE", "TIME", "ANGLE", "DISTANCE", "INDEX",]))
+
+CHANNEL_TYPE_TO_STRING = CHANNEL_TYPE_TO_DESCRIPTION = {
+    CHANNEL_TYPE_VALUE: "VALUE",
     CHANNEL_TYPE_VLSD: "VLSD",
-    CHANNEL_TYPE_MASTER: "master",
-    CHANNEL_TYPE_VIRTUAL_MASTER: "virtual master",
-    CHANNEL_TYPE_SYNC: "sync",
+    CHANNEL_TYPE_MASTER: "MASTER",
+    CHANNEL_TYPE_VIRTUAL_MASTER: "VIRTUAL MASTER",
+    CHANNEL_TYPE_SYNC: "SYNC",
     CHANNEL_TYPE_MLSD: "MLSD",
-    CHANNEL_TYPE_VIRTUAL: "virtual",
+    CHANNEL_TYPE_VIRTUAL: "VIRTUAL",
 }
 
 MASTER_TYPES = {CHANNEL_TYPE_MASTER, CHANNEL_TYPE_VIRTUAL_MASTER}
@@ -98,6 +124,25 @@ CONVERSION_TYPE_TTAB = 9
 CONVERSION_TYPE_TRANS = 10
 CONVERSION_TYPE_BITFIELD = 11
 
+CONVERSION_TYPE_TO_STRING = dict(
+    enumerate(
+        [
+            "NON",
+            "LIN",
+            "RAT",
+            "ALG",
+            "TABI",
+            "TAB",
+            "RTAB",
+            "TABX",
+            "RTABX",
+            "TTAB",
+            "TRANS",
+            "BITFIELD",
+        ]
+    )
+)
+
 CONV_RAT_TEXT = "(P1 * X**2 + P2 * X + P3) / (P4 * X**2 + P5 * X + P6)"
 
 TABULAR_CONVERSIONS = {
@@ -139,6 +184,15 @@ SOURCE_IO = 3
 SOURCE_TOOL = 4
 SOURCE_USER = 5
 
+SOURCE_TYPE_TO_STRING = {
+    SOURCE_OTHER: "OTHER",
+    SOURCE_ECU: "ECU",
+    SOURCE_BUS: "BUS",
+    SOURCE_IO: "IO",
+    SOURCE_TOOL: "TOOL",
+    SOURCE_USER: "USER",
+}
+
 BUS_TYPE_NONE = 0
 BUS_TYPE_OTHER = 1
 BUS_TYPE_CAN = 2
@@ -149,6 +203,18 @@ BUS_TYPE_K_LINE = 6
 BUS_TYPE_ETHERNET = 7
 BUS_TYPE_USB = 8
 
+BUS_TYPE_TO_STRING = {
+    BUS_TYPE_NONE: "NONE",
+    BUS_TYPE_OTHER: "OTHER",
+    BUS_TYPE_CAN: "CAN",
+    BUS_TYPE_LIN: "LIN",
+    BUS_TYPE_MOST: "MOST",
+    BUS_TYPE_FLEXRAY: "FLEXRAY",
+    BUS_TYPE_K_LINE: "K_LINE",
+    BUS_TYPE_ETHERNET: "ETHERNET",
+    BUS_TYPE_USB: "USB",
+}
+
 EVENT_TYPE_RECORDING = 0
 EVENT_TYPE_RECORDING_INTERRUPT = 1
 EVENT_TYPE_ACQUISITION_INTERRUPT = 2
@@ -157,6 +223,16 @@ EVENT_TYPE_STOP_RECORDING_TRIGGER = 4
 EVENT_TYPE_TRIGGER = 5
 EVENT_TYPE_MARKER = 6
 
+EVENT_TYPE_TO_STRING = {
+    EVENT_TYPE_RECORDING: "Recording",
+    EVENT_TYPE_RECORDING_INTERRUPT: "REcording interrupt",
+    EVENT_TYPE_ACQUISITION_INTERRUPT: "Acquisition interrupt",
+    EVENT_TYPE_START_RECORDING_TRIGGER: "Start recording trigger",
+    EVENT_TYPE_STOP_RECORDING_TRIGGER: "Stop recording trigger",
+    EVENT_TYPE_TRIGGER: "Trigger",
+    EVENT_TYPE_MARKER: "Marker",
+}
+
 EVENT_SYNC_TYPE_S = 1
 EVENT_SYNC_TYPE_RAD = 2
 EVENT_SYNC_TYPE_M = 3
@@ -239,6 +315,14 @@ FLAG_CG_PLAIN_BUS_EVENT = 1 << 2
 FLAG_CG_REMOTE_MASTER = 1 << 3
 FLAG_CG_EVENT_GROUP = 1 << 4
 
+FLAG_CG_TO_STRING = {
+    FLAG_CG_VLSD: "VLSD",
+    FLAG_CG_BUS_EVENT: "BUS_EVENT",
+    FLAG_CG_PLAIN_BUS_EVENT: "PLAIN_BUS_EVENT",
+    FLAG_CG_REMOTE_MASTER: "REMOTE_MASTER",
+    FLAG_CG_EVENT_GROUP: "EVENT_GROUP",
+}
+
 FLAG_CN_ALL_INVALID = 1
 FLAG_CN_INVALIDATION_PRESENT = 1 << 1
 FLAG_CN_PRECISION = 1 << 2
@@ -255,6 +339,24 @@ FLAG_CN_DEFAULT_X = 1 << 12
 FLAG_CN_EVENT_SIGNAL = 1 << 13
 FLAG_CN_VLSD = 1 << 14
 
+FLAG_CN_TO_STRING = {
+    FLAG_CN_ALL_INVALID: "ALL_INVALID",
+    FLAG_CN_INVALIDATION_PRESENT: "INVALIDATION_PRESENT",
+    FLAG_CN_PRECISION: "PRECISION",
+    FLAG_CN_VALUE_RANGE: "VALUE_RANGE",
+    FLAG_CN_LIMIT_RANGE: "LIMIT_RANGE",
+    FLAG_CN_EXTENDED_LIMIT_RANGE: "EXTENDED_LIMIT_RANGE",
+    FLAG_CN_DISCRETE: "DISCRETE",
+    FLAG_CN_CALIBRATION: "CALIBRATION",
+    FLAG_CN_CALCULATED: "CALCULATED",
+    FLAG_CN_VIRTUAL: "VIRTUAL",
+    FLAG_CN_BUS_EVENT: "BUS_EVENT",
+    FLAG_CN_MONOTONOUS: "MONOTONOUS",
+    FLAG_CN_DEFAULT_X: "DEFAULT_X",
+    FLAG_CN_EVENT_SIGNAL: "EVENT_SIGNAL",
+    FLAG_CN_VLSD: "VLSD",
+}
+
 FLAG_CC_PRECISION = 1
 FLAG_CC_RANGE = 1 << 1
 
