@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
+from PyQt5 import QtCore, QtGui, QtWidgets
+
 from ..ui import resource_rc as resource_rc
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
-from PyQt5 import QtCore
 
 
 class TabularValuesDialog(QtWidgets.QDialog):
