@@ -1,26 +1,22 @@
 # -*- coding: utf-8 -*-
+from pathlib import Path
 from threading import Thread
 from time import sleep
-from pathlib import Path
 
 from natsort import natsorted
 import psutil
+from PyQt5 import QtCore, QtGui, QtWidgets
 
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
-from PyQt5 import QtCore
-
-from ..ui import resource_rc as resource_rc
-from ..ui.batch_widget import Ui_batch_widget
-
+from ...blocks.utils import extract_cncomment_xml, MdfException
 from ...mdf import MDF, SUPPORTED_VERSIONS
 from ...signal import Signal
-from ...blocks.utils import MdfException, extract_cncomment_xml
-from ..utils import TERMINATED, run_thread_with_progress, setup_progress
+from ..ui import resource_rc as resource_rc
+from ..ui.batch_widget import Ui_batch_widget
+from ..utils import run_thread_with_progress, setup_progress, TERMINATED
+from .list import MinimalListWidget
 from .search import SearchWidget
 from .tree import TreeWidget
 from .tree_item import TreeItem
-from .list import MinimalListWidget
 
 
 class BatchWidget(Ui_batch_widget, QtWidgets.QWidget):
