@@ -5,14 +5,15 @@ from PyQt5 import QtWidgets
 
 class TreeItem(QtWidgets.QTreeWidgetItem):
 
-    __slots__ = "entry", "name"
+    __slots__ = "entry", "name", "mdf_uuid"
 
-    def __init__(self, entry, name="", parent=None, strings=None):
+    def __init__(self, entry, name="", parent=None, strings=None, mdf_uuid=None):
 
         super().__init__(parent, strings)
 
         self.entry = entry
         self.name = name
+        self.mdf_uuid = mdf_uuid
 
     def __lt__(self, otherItem):
         column = self.treeWidget().sortColumn()
@@ -41,4 +42,4 @@ class TreeItem(QtWidgets.QTreeWidgetItem):
             return self.text(column) < otherItem.text(column)
 
     def __del__(self):
-        self.entry = self.name = None
+        self.entry = self.name = self.mdf_uuid = None
